PieceMeal
=========

A dead simple plugin manager for Python. No sidecar manifests. No entry points. Simply inherit from `piecemeal.PieceMealPlugin`, point the `piecemeal.PluginManager` at a directory, file or module and your plugins are loaded.

Docs to follow...
